# recrutement de masse
# choix entre deux branches de longueur égale
# Modele
# - arrive une fourmis par unité de temps au branchement
# - chofracDomix selon p(A) = (k+Ai)^n/((k+Ai)^n + (k+Bi)^n) 
#	Ai nombre de fourmis passé sur la branche A au temps i
#	Bi nombre de fourmis passé sur la branche B au temps i
#	k=20, n=2 paramètres empiriques estimés par des données (diapos 27)
# - on simule 2000 pas i, et on calcule pourcentage total du traffic cumulé sur A 
rm(list=ls()) # faire le ménage

# une seule expérience virtuelle
nbPas = 2000
A = rep(0,nbPas+1)
B = rep(0,nbPas+1)
t = seq(0,nbPas)
k=20
n=2 # fourmis: n=2; abeilles: n=1
for (i in 1:nbPas) {
	pA = (k+A[i])^n/((k+A[i])^n + (k+B[i])^n)
	if (runif(1) < pA) {
		A[i+1] = A[i]+ 1
		B[i+1] = B[i]
	} else {
		A[i+1] = A[i]
		B[i+1] = B[i]+ 1
	}
}
if (A[nbPas] > B[nbPas]) {
	fracDom = A/(A+B)
} else {
	fracDom = B/(A+B)
}
fracDom[is.nan(fracDom)]=0.5 # si A = B = 0
plot(t, 100*fracDom, xlab="Temps", ylab="Pourcentage sur branche dominante",type='l', 
	main="Dynamique du choix",ylim=c(0,100), col="red", lwd=2)

# 1000 expériences pour reconstruire la courbe en U
n=2.0 # jouer avec la valeur de n = 1, 1.2, 1.5, 1.8, 2.0, 2.5; reproduire la courbe sur la diapos 26
nbRep = 1000
fracDom = rep(0, nbPas+1)
for (rep in 1:nbRep) {
	A = rep(0,nbPas)
	B = rep(0,nbPas)
	for (i in 1:nbPas) {
		pA = (k+A[i])^n/((k+A[i])^n + (k+B[i])^n)
		if (runif(1) <= pA) {
			A[i+1] = A[i]+ 1
			B[i+1] = B[i]
		} else {
			A[i+1] = A[i]
			B[i+1] = B[i]+ 1
		}
	}
	if (A[nbPas] > B[nbPas]) {
		fracDom = fracDom + A/(A+B)
	} else {
		fracDom = fracDom + B/(A+B)
	}
}
fracDom = fracDom / nbRep
fracDom[is.nan(fracDom)]=0.5
par(bg='black', fg='white', col.lab='white',col.axis='white',col.main='white')
plot(t, fracDom, xlab="Nombre de passages de fourmis", 
	ylab="Pourcentage sur branche dominante",type='l', 
	main="Courbe de calibration de Deneubourg",ylim=c(0.4,1), col="yellow", lwd=3, yaxt="n")
axis(2, at=seq(0,1,by=.2), labels=paste(100*seq(0,1,by=.2), "%"),las=1)

# donnees
don = read.table("choixData.txt",h=T)
don
lines(don$temps,don$pourcentage/100,type='b',col='red',lwd=2)

