rm(list=ls())
# auteur: Christian Jost
# date: 17/05/2019
# encodage: utf-8
list.files()
#### lecture donnees ####
don = read.table("LinepithemaHumile-IRES-2019.csv",h=T,sep=";")
summary(don)
(colos = levels(don$groupe))

#### visualisation manip par manip ####
layout(matrix(1:6,nrow=2,byrow=T))
for (k in 1:length(colos)) {
	tmp = subset(don,groupe==colos[k])
	cumAller = cumsum(tmp$aller.A+tmp$aller.B)
	cumRetour = cumsum(tmp$retour.A+tmp$retour.B)
	aLaSource = cumAller - cumRetour
	aLaSource[aLaSource < 0] = 0
	plot(tmp$temps.min,aLaSource,type='l',xlab="Temps (min)",
		ylab="Fourmis à la source", main=paste("Données groupe",colos[k]))
}

#### nombre de fourmis à la source (moyenne +- es)
manips = c(1,2,3,4,5)
layout(matrix(1:1,nrow=1))
aLaSource = matrix(0,nrow=25,ncol=length(manips))
for (k in 1:length(manips)) {
	tmp = subset(don,groupe==colos[manips[k]])
	cumAller = cumsum(tmp$aller.A+tmp$aller.B)
	cumRetour = cumsum(tmp$retour.A+tmp$retour.B)
	tmp2 = cumAller - cumRetour
	aLaSource[,k] = tmp2[1:25]
}
alsMoy = apply(aLaSource[1:25,],1,mean)
alsES = apply(aLaSource[1:25,],1,sd)/sqrt(length(manips))
plot(1:25,alsMoy,type='l',xlab="Temps (min)", ylab="Nombre a la source (moy +- es)",ylim=c(0,max(alsMoy+alsES)),main="Nombre de fourmis à la source")
segments(1:25,alsMoy+alsES,1:25,alsMoy-alsES)

#### comparaison flux A et flux B
layout(matrix(1:2,nrow=1))
brA = matrix(0,nrow=25,ncol=length(manips))
brB = matrix(0,nrow=25,ncol=length(manips))
for (k in 1:length(manips)) {
	tmp = subset(don,groupe==colos[manips[k]])
	# remplacer NA par 0 (sinon on ne peut pas calculer le cumul
	tmp[is.na(tmp)]=0
	fluxA = tmp$aller.A+tmp$retour.A
	fluxB = tmp$aller.B+tmp$retour.B
	brA[,k]=fluxA
	brB[,k]=fluxB
}
brAmoy = apply(brA,1,mean)
brBmoy = apply(brB,1,mean)
brAse = apply(brA,1,sd)/sqrt(length(colos))
brBse = apply(brB,1,sd)/sqrt(length(colos))
plot(1:25,brAmoy,type='l',xlab="Temps (min)", ylab="Flux (moy +- es)",ylim=c(0,max(c(brAmoy+brAse,brBmoy+brBse))+25),main="Flux (aller + retour)", col="blue")
segments(1:25, brAmoy+brAse,1:25, brAmoy-brAse,col="blue")
lines(1:25,brBmoy,col='red')
segments(1:25, brBmoy+brBse,1:25, brBmoy-brBse,col='red')
legend('topleft',legend=c("Branche A","Branche B"),col=c('blue','red'),lty=c('solid','solid'),ncol=1)
text(0,50,"(a)",pos=4,cex=1.3)
shapiro.test(brA[25,]-brB[25,])
# W = 0.9256, p-value = 0.3356
t.test(brA[25,],brB[25,],paired=T)

# même chose pour les flux cumulés
brA = matrix(0,nrow=25,ncol=length(manips))
brB = matrix(0,nrow=25,ncol=length(manips))
for (k in 1:length(manips)) {
	tmp = subset(don,groupe==colos[manips[k]])
	# remplacer NA par 0 (sinon on ne peut pas calculer le cumul
	tmp[is.na(tmp)]=0
	fluxA = tmp$aller.A+tmp$retour.A
	fluxB = tmp$aller.B+tmp$retour.B
	brA[,k]=cumsum(fluxA)
	brB[,k]=cumsum(fluxB)
}
brAmoy = apply(brA,1,mean)
brBmoy = apply(brB,1,mean)
brAse = apply(brA,1,sd)/sqrt(length(colos))
brBse = apply(brB,1,sd)/sqrt(length(colos))
plot(1:25,brAmoy,type='l',xlab="Temps (min)", ylab="Flux cumulé (moy +- es)",ylim=c(0,max(c(brAmoy+brAse,brBmoy+brBse))+250),main="Flux cumulé (aller+retour)",col="blue")
segments(1:25, brAmoy+brAse,1:25, brAmoy-brAse,col="blue")
lines(1:25,brBmoy,col='red')
segments(1:25, brBmoy+brBse,1:25, brBmoy-brBse,col='red')
legend('topleft',legend=c("Branche A","Branche B"),col=c('blue','red'),lty=c('solid','solid'),ncol=1)
text(0,500,"(b)",pos=4,cex=1.3)

# comparaison statistiques a la fin
brA[25,] #
brB[25,] #
shapiro.test(brA[25,]-brB[25,])
# W = 0.9256, p-value = 0.3356
t.test(brA[25,],brB[25,],paired=T)
# pourcentage sur A à la fin
propAfin = brA[25,]/(brA[25,]+brB[25,])
hist(propAfin, xlim=c(0,1))

#### exemple une seule manip a la fois ####
k = 5
layout(matrix(1:3,nrow=1))
tmp = subset(don,groupe==colos[manips[k]])
fluxAa = tmp$aller.A
fluxAr = tmp$retour.A
fluxBa = tmp$aller.B
fluxBr = tmp$retour.B
plot(1:25,fluxAa,type='l',ylim=c(0,max(c(fluxAa,fluxAr,fluxBa,fluxBr))), 
	main = "Nombre de fourmis comptés", xlab="Temps (min)", 
	ylab = "Nombre de fourmis", col="blue")
lines(1:25,fluxAr,lty="dashed",col="blue")
lines(1:25,fluxBa,lty="solid",col="red")
lines(1:25,fluxBr,lty="dashed",col="red")
legend('topright',legend=c(expression(a["A,t"]),expression(r["A,t"]),
	expression(a["B,t"]),expression(r["B,t"])), 
	lty = c("solid","dashed","solid","dashed"), 
	col = c("blue","blue","red","red"))
text(0,45,"(a)",pos=4,cex=1.3)

aLaSource = cumsum(fluxAa+fluxBa)- cumsum(fluxAr+fluxBr)
plot(1:25, aLaSource,type="l", xlab="Temps (min)", ylab = "Nombre de fourmis",
	main="Fourmis à la source")
text(0,135,"(b)",pos=4,cex=1.3)

plot(1:25, cumsum(fluxAa+fluxAr),type="l", xlab="Temps (min)", ylab = "Flux cumulé",
	main="Flux cumulé (aller + retour)", col="blue")
lines(1:25, cumsum(fluxBa+fluxBr),col="red")
legend('topleft', legend=c("Branche A","Branche B"), col=c("blue","red"),
	lty = c("solid","solid"))
text(0,750,"(c)",pos=4,cex=1.3)

# autocorrelation
layout(matrix(1:2,nrow=1))
acf(fluxAa, main = "Auto-corrélation aller sur A")
text(2,0.8,"(a)",cex=1.3,pos=4)
acf(cumsum(fluxAa+fluxAr), main = "Auto-corrélation flux cumulé aller+retour")
text(5,0.8,"(b)",cex=1.3,pos=4)

